PIconnect.PI module
===================

.. autoclass:: PIconnect.PI.PIServer
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    :exclude-members: servers, default_server

    .. autoattribute:: servers
        :annotation: Dictionary of known servers, as reported by the SDK

    .. autoattribute:: default_server
        :annotation: Default server, as reported by the SDK

.. autoclass:: PIconnect.PI.PIPoint
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
